==> kubernetes-model-resource-6.13.0-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha2/ResourceRequestFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ResourceRequestFluent<A extends ResourceRequestFluent<A>> extends BaseFluent<A>{
  public ResourceRequestFluent() {
  }
  
  public ResourceRequestFluent(ResourceRequest instance) {
    this.copyInstance(instance);
  }
  private NamedResourcesRequestBuilder namedResources;
  private Map<String,Object> vendorParameters;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ResourceRequest instance) {
    instance = (instance != null ? instance : new ResourceRequest());
    if (instance != null) {
          this.withNamedResources(instance.getNamedResources());
          this.withVendorParameters(instance.getVendorParameters());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public NamedResourcesRequest buildNamedResources() {
    return this.namedResources != null ? this.namedResources.build() : null;
  }
  
  public A withNamedResources(NamedResourcesRequest namedResources) {
    this._visitables.remove("namedResources");
    if (namedResources != null) {
        this.namedResources = new NamedResourcesRequestBuilder(namedResources);
        this._visitables.get("namedResources").add(this.namedResources);
    } else {
        this.namedResources = null;
        this._visitables.get("namedResources").remove(this.namedResources);
    }
    return (A) this;
  }
  
  public boolean hasNamedResources() {
    return this.namedResources != null;
  }
  
  public A withNewNamedResources(String selector) {
    return (A)withNamedResources(new NamedResourcesRequest(selector));
  }
  
  public NamedResourcesNested<A> withNewNamedResources() {
    return new NamedResourcesNested(null);
  }
  
  public NamedResourcesNested<A> withNewNamedResourcesLike(NamedResourcesRequest item) {
    return new NamedResourcesNested(item);
  }
  
  public NamedResourcesNested<A> editNamedResources() {
    return withNewNamedResourcesLike(java.util.Optional.ofNullable(buildNamedResources()).orElse(null));
  }
  
  public NamedResourcesNested<A> editOrNewNamedResources() {
    return withNewNamedResourcesLike(java.util.Optional.ofNullable(buildNamedResources()).orElse(new NamedResourcesRequestBuilder().build()));
  }
  
  public NamedResourcesNested<A> editOrNewNamedResourcesLike(NamedResourcesRequest item) {
    return withNewNamedResourcesLike(java.util.Optional.ofNullable(buildNamedResources()).orElse(item));
  }
  
  public A addToVendorParameters(String key,Object value) {
    if(this.vendorParameters == null && key != null && value != null) { this.vendorParameters = new LinkedHashMap(); }
    if(key != null && value != null) {this.vendorParameters.put(key, value);} return (A)this;
  }
  
  public A addToVendorParameters(Map<String,Object> map) {
    if(this.vendorParameters == null && map != null) { this.vendorParameters = new LinkedHashMap(); }
    if(map != null) { this.vendorParameters.putAll(map);} return (A)this;
  }
  
  public A removeFromVendorParameters(String key) {
    if(this.vendorParameters == null) { return (A) this; }
    if(key != null && this.vendorParameters != null) {this.vendorParameters.remove(key);} return (A)this;
  }
  
  public A removeFromVendorParameters(Map<String,Object> map) {
    if(this.vendorParameters == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.vendorParameters != null){this.vendorParameters.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getVendorParameters() {
    return this.vendorParameters;
  }
  
  public <K,V>A withVendorParameters(Map<String,Object> vendorParameters) {
    if (vendorParameters == null) {
      this.vendorParameters = null;
    } else {
      this.vendorParameters = new LinkedHashMap(vendorParameters);
    }
    return (A) this;
  }
  
  public boolean hasVendorParameters() {
    return this.vendorParameters != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ResourceRequestFluent that = (ResourceRequestFluent) o;
    if (!java.util.Objects.equals(namedResources, that.namedResources)) return false;
    if (!java.util.Objects.equals(vendorParameters, that.vendorParameters)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(namedResources,  vendorParameters,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (namedResources != null) { sb.append("namedResources:"); sb.append(namedResources + ","); }
    if (vendorParameters != null && !vendorParameters.isEmpty()) { sb.append("vendorParameters:"); sb.append(vendorParameters + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class NamedResourcesNested<N> extends NamedResourcesRequestFluent<NamedResourcesNested<N>> implements Nested<N>{
    NamedResourcesNested(NamedResourcesRequest item) {
      this.builder = new NamedResourcesRequestBuilder(this, item);
    }
    NamedResourcesRequestBuilder builder;
    
    public N and() {
      return (N) ResourceRequestFluent.this.withNamedResources(builder.build());
    }
    
    public N endNamedResources() {
      return and();
    }
    
  
  }

}

==> kubernetes-model-resource-7.0.1-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha2/ResourceRequestFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ResourceRequestFluent<A extends ResourceRequestFluent<A>> extends BaseFluent<A>{
  public ResourceRequestFluent() {
  }
  
  public ResourceRequestFluent(ResourceRequest instance) {
    this.copyInstance(instance);
  }
  private NamedResourcesRequestBuilder namedResources;
  private Object vendorParameters;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ResourceRequest instance) {
    instance = (instance != null ? instance : new ResourceRequest());
    if (instance != null) {
          this.withNamedResources(instance.getNamedResources());
          this.withVendorParameters(instance.getVendorParameters());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public NamedResourcesRequest buildNamedResources() {
    return this.namedResources != null ? this.namedResources.build() : null;
  }
  
  public A withNamedResources(NamedResourcesRequest namedResources) {
    this._visitables.remove("namedResources");
    if (namedResources != null) {
        this.namedResources = new NamedResourcesRequestBuilder(namedResources);
        this._visitables.get("namedResources").add(this.namedResources);
    } else {
        this.namedResources = null;
        this._visitables.get("namedResources").remove(this.namedResources);
    }
    return (A) this;
  }
  
  public boolean hasNamedResources() {
    return this.namedResources != null;
  }
  
  public A withNewNamedResources(String selector) {
    return (A)withNamedResources(new NamedResourcesRequest(selector));
  }
  
  public NamedResourcesNested<A> withNewNamedResources() {
    return new NamedResourcesNested(null);
  }
  
  public NamedResourcesNested<A> withNewNamedResourcesLike(NamedResourcesRequest item) {
    return new NamedResourcesNested(item);
  }
  
  public NamedResourcesNested<A> editNamedResources() {
    return withNewNamedResourcesLike(java.util.Optional.ofNullable(buildNamedResources()).orElse(null));
  }
  
  public NamedResourcesNested<A> editOrNewNamedResources() {
    return withNewNamedResourcesLike(java.util.Optional.ofNullable(buildNamedResources()).orElse(new NamedResourcesRequestBuilder().build()));
  }
  
  public NamedResourcesNested<A> editOrNewNamedResourcesLike(NamedResourcesRequest item) {
    return withNewNamedResourcesLike(java.util.Optional.ofNullable(buildNamedResources()).orElse(item));
  }
  
  public Object getVendorParameters() {
    return this.vendorParameters;
  }
  
  public A withVendorParameters(Object vendorParameters) {
    this.vendorParameters = vendorParameters;
    return (A) this;
  }
  
  public boolean hasVendorParameters() {
    return this.vendorParameters != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ResourceRequestFluent that = (ResourceRequestFluent) o;
    if (!java.util.Objects.equals(namedResources, that.namedResources)) return false;
    if (!java.util.Objects.equals(vendorParameters, that.vendorParameters)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(namedResources,  vendorParameters,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (namedResources != null) { sb.append("namedResources:"); sb.append(namedResources + ","); }
    if (vendorParameters != null) { sb.append("vendorParameters:"); sb.append(vendorParameters + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class NamedResourcesNested<N> extends NamedResourcesRequestFluent<NamedResourcesNested<N>> implements Nested<N>{
    NamedResourcesNested(NamedResourcesRequest item) {
      this.builder = new NamedResourcesRequestBuilder(this, item);
    }
    NamedResourcesRequestBuilder builder;
    
    public N and() {
      return (N) ResourceRequestFluent.this.withNamedResources(builder.build());
    }
    
    public N endNamedResources() {
      return and();
    }
    
  
  }

}
